<?php

// page used for creating new petitions
// and for editing existing petitions
function dk_speakup_edit_page() {
	// check security: ensure user has authority
	if ( !current_user_can( 'publish_posts' ) ) wp_die( 'Insufficient privileges: You need to be an editor to do that.' );

	global $wpdb, $db_petitions;
	$action  = isset( $_REQUEST['action'] ) ? $_REQUEST['action'] : '';
	$id      = isset( $_REQUEST['id'] ) ? $_REQUEST['id'] : '';
	$options = get_option( 'dk_speakup_options' );

	// default expiration date is one week ahead
	$next_week = strtotime( current_time( 'mysql', 0 ) ) + ( 60 * 60 * 24 * 7 );

	$message_update = '';

	switch( $action ) {
		// insert a new petition in db
		// then display form for editing the new petition
		case 'create' :
			// security: ensure user has intention
			check_admin_referer( 'dk_speakup-create_petition' );

			// default form values
			$petition_title     = __( 'No Title', 'dk_speakup' );
			$petition_email     = '';
			$petition_subject   = '';
			$petition_greeting  = '';
			$petition_message   = '';
			$twitter_message    = '';
			$custom_field_label = '';
			$email_optin_label  = '';
			$display_address    = 0;

			// clean input data for placing in db
			if ( isset( $_POST['petition_title'] ) && $_POST['petition_title'] != '' ) {
				$petition_title = esc_html( stripslashes( $_POST['petition_title'] ) );
			}
			if ( isset( $_POST['petition_email'] ) && is_email( $_POST['petition_email'] ) ) {
				$petition_email = $_POST['petition_email'];
			}
			if ( isset( $_POST['petition_subject'] ) ) {
				$petition_subject = esc_html( stripslashes( $_POST['petition_subject'] ) );
			}
			if ( isset( $_POST['petition_greeting'] ) ) {
				$petition_greeting = esc_html( stripslashes( $_POST['petition_greeting'] ) );
			}
			if ( isset( $_POST['petition_message'] ) ) {
				$petition_message = esc_html( stripslashes( wp_strip_all_tags( $_POST['petition_message'] ) ) );
			}
			if ( isset( $_POST['twitter_message'] ) ) {
				$twitter_message = esc_html( stripslashes( wp_strip_all_tags( $_POST['twitter_message'] ) ) );
			}
			if ( isset( $_POST['custom-field-label'] ) ) {
				$custom_field_label = esc_html( stripslashes( wp_strip_all_tags( $_POST['custom-field-label'] ) ) );
			}
			if ( isset( $_POST['email-optin-label'] ) ) {
				$email_optin_label = esc_html( stripslashes( wp_strip_all_tags( $_POST['email-optin-label'] ) ) );
			}

			$confirm            = ( isset( $_POST['confirm'] ) && $_POST['confirm'] == 'on' ) ? '1' : '0';
			$has_signature_goal = ( isset( $_POST['has_signature_goal'] ) && $_POST['has_signature_goal'] == 'on' ) ? '1' : '0';
			$send_email         = ( isset( $_POST['send_email'] ) && $_POST['send_email'] == 'on' ) ? '0' : '1';
			$signature_goal     = ( isset( $_POST['signature_goal'] ) ) ? absint( $_POST['signature_goal'] ) : '0';

			// set values for optional address fields
			if ( isset( $_POST['display-address'] ) && $_POST['display-address'] == 'on' ) {
				$display_address = 1;
				$address_fields = array();

				if ( isset( $_POST['street'] )   && $_POST['street'] == 'on' )   array_push( $address_fields, 'street' );
				if ( isset( $_POST['city'] )     && $_POST['city'] == 'on' )     array_push( $address_fields, 'city' );
				if ( isset( $_POST['state'] )    && $_POST['state'] == 'on' )    array_push( $address_fields, 'state' );
				if ( isset( $_POST['postcode'] ) && $_POST['postcode'] == 'on' ) array_push( $address_fields, 'postcode' );
				if ( isset( $_POST['country'] )  && $_POST['country'] == 'on' )  array_push( $address_fields, 'country' );

				$address_fields = serialize( $address_fields );
			}
			else {
				$address_fields = serialize( array( 'none' ) );
			}

			$display_custom_field = ( isset( $_POST['display-custom-field'] ) && $_POST['display-custom-field'] == 'on' ) ? '1' : '0';
			$display_email_optin =  ( isset( $_POST['display-email-optin'] )  && $_POST['display-email-optin']  == 'on' ) ? '1' : '0';
			$created_date = current_time( 'mysql', 0 );

			// handle expiration dates
			$expires = ( isset( $_POST['expires'] ) && $_POST['expires'] == 'on' ) ? '1' : '0';
			$year    = absint( $_POST['year'] );
			$month   = absint( $_POST['month'] );
			$day     = absint( $_POST['day'] );
			$hour    = absint( $_POST['hour'] );
			$minutes = absint( $_POST['minutes'] );
			if ( $expires == '1' ) {
				// force dates to be rational (ex: converts Jan 45 to Feb 14)
				$timestamp       = mktime( $hour, $minutes, 0, $month, $day, $year );
				$year            = date( 'Y', $timestamp );
				$month           = date( 'm', $timestamp );
				$day             = date( 'd', $timestamp );
				$hour            = date( 'H', $timestamp );
				$minutes         = date( 'i', $timestamp );
				$expiration_date = $year . '-' . $month . '-' . $day . ' ' . $hour . ':' . $minutes;
			}
			else {
				$expiration_date = '0000-00-00 00:00';
			}

			// add petition to db
			$sql = "
				INSERT INTO $db_petitions (
					`petition_title`, `petition_email`, `petition_subject`, `petition_greeting`, `petition_message`, `address_fields`,
					`expires`, `expiration_date`, `created_date`, `has_signature_goal`, `signature_goal`, `send_email`, `twitter_message`, 
					`confirm`, `display_custom_field`, `custom_field_label`, `display_email_optin`, `email_optin_label`
				)
				VALUES (
					'$petition_title', '$petition_email', '$petition_subject', '$petition_greeting', '$petition_message', '$address_fields', 
					'$expires', '$expiration_date', '$created_date', '$has_signature_goal', '$signature_goal', '$send_email', '$twitter_message', 
					'$confirm', '$display_custom_field', '$custom_field_label', '$display_email_optin', '$email_optin_label' 
				)
			";
			$wpdb->query( $sql );

			// set up strings for page display
			$id = mysql_insert_id(); // grab the id of new petition we just added to the db
			$page_title              = __( 'Edit Email Petition', 'dk_speakup' );
			$nonce                   = 'dk_speakup-update_petition' . $id;
			$action                  = 'update';
			$emailpetition_shortcode = '[emailpetition id="' . $id . '"]';
			$signaturelist_shortcode = '[signaturelist id="' . $id . '"]';
			$start_tag               = '<strong>';
			$end_tag                 =  '</strong>';
			$message_text            = __( 'Petition created. Use %1$s %2$s %3$s to display in a page or post. Use %1$s %4$s %3$s to display the signatures list.', 'dk_speakup' );
			$message_update          = sprintf( $message_text, $start_tag, $emailpetition_shortcode, $end_tag, $signaturelist_shortcode );
			$button_text             = __( 'Update Petition', 'dk_speakup' );
			$address_fields = unserialize( $address_fields );

			break;

		// 'edit' is only called from text links on the Email Petitions page
		// displays existing petition for alteration and submits to 'update'
		case 'edit' :
			// security: ensure user has intention
			check_admin_referer( 'dk_speakup-edit_petition' . $id );

			// prepare db query
			$sql = "
				SELECT *
				FROM `$db_petitions`
				WHERE `id` = '$id'
			";
			$results = $wpdb->get_row( $sql );

			// set up existing values to display in form
			$petition_title       = $results->petition_title;
			$petition_email       = $results->petition_email;
			$petition_subject     = $results->petition_subject;
			$petition_greeting    = $results->petition_greeting;
			$petition_message     = $results->petition_message;
			$twitter_message      = $results->twitter_message;
			$confirm              = $results->confirm;
			$has_signature_goal   = $results->has_signature_goal;
			$signature_goal       = $results->signature_goal;
			$address_fields       = unserialize( $results->address_fields );
			$display_custom_field = $results->display_custom_field;
			$custom_field_label   = $results->custom_field_label;
			$display_email_optin  = $results->display_email_optin;
			$email_optin_label    = $results->email_optin_label;
			$send_email           = $results->send_email;

			// set up expiration date
			$expires = $results->expires;
			$expiration_date = $results->expiration_date;
			if ( $expires == '1' ) {
				$year    = date( 'Y', strtotime( $expiration_date ) );
				$month   = date( 'm', strtotime( $expiration_date ) );
				$day     = date( 'd', strtotime( $expiration_date ) );
				$hour    = date( 'H', strtotime( $expiration_date ) );
				$minutes = date( 'i', strtotime( $expiration_date ) );
			}
			else {
				$month   = date( 'm', $next_week );
				$day     = date( 'd', $next_week );
				$year    = date( 'Y', $next_week );
				$hour    = '16';
				$minutes = '20';
			}

			// set up strings for page display
			$page_title  = __( 'Edit Email Petition', 'dk_speakup' );
			$nonce       = 'dk_speakup-update_petition' . $id;
			$action      = 'update';
			$button_text = __( 'Update Petition', 'dk_speakup' );

			break;

		// alter an existing petition
		case 'update' :
			// security: ensure user has intention
			check_admin_referer( 'dk_speakup-update_petition' . $id );

			// clean input data for placing in db
			$petition_title       = esc_html( stripslashes( $_POST['petition_title'] ) );
			$petition_email       = $_POST['petition_email'];
			$petition_subject     = esc_html( stripslashes( $_POST['petition_subject'] ) );
			$petition_greeting    = esc_html( stripslashes( $_POST['petition_greeting'] ) );
			$petition_message     = esc_html( stripslashes( wp_strip_all_tags( $_POST['petition_message'] ) ) );
			$twitter_message      = esc_html( stripslashes( wp_strip_all_tags( $_POST['twitter_message'] ) ) );
			$confirm              = ( isset( $_POST['confirm'] ) && $_POST['confirm'] == 'on' ) ? '1' : '0';
			$expires              = ( isset( $_POST['expires'] ) && $_POST['expires'] == 'on' ) ? '1' : '0';
			$display_custom_field = ( isset( $_POST['display-custom-field'] ) && $_POST['display-custom-field'] == 'on' ) ? '1' : '0';
			$custom_field_label   = esc_html( stripslashes( wp_strip_all_tags( $_POST['custom-field-label'] ) ) );
			$display_email_optin  = ( isset( $_POST['display-email-optin'] ) && $_POST['display-email-optin'] == 'on' ) ? '1' : '0';
			$email_optin_label    = esc_html( stripslashes( wp_strip_all_tags( $_POST['email-optin-label'] ) ) );
			$send_email           = ( isset( $_POST['send_email'] ) && $_POST['send_email'] == 'on' ) ? '0' : '1';
			if ( isset( $_POST['has_signature_goal'] ) && $_POST['has_signature_goal'] == 'on' ) {
				$has_signature_goal = '1';
				$signature_goal = absint( $_POST['signature_goal'] );
			}
			else {
				$has_signature_goal = '0';
				$signature_goal = '0';
			}

			// set values for optional address fields
			if ( isset( $_POST['display-address'] ) && $_POST['display-address'] == 'on' ) {
				$display_address = 1;
				$address_fields = array();

				if ( isset( $_POST['street'] )   && $_POST['street'] == 'on' )   array_push( $address_fields, 'street' );
				if ( isset( $_POST['city'] )     && $_POST['city'] == 'on' )     array_push( $address_fields, 'city' );
				if ( isset( $_POST['state'] )    && $_POST['state'] == 'on' )    array_push( $address_fields, 'state' );
				if ( isset( $_POST['postcode'] ) && $_POST['postcode'] == 'on' ) array_push( $address_fields, 'postcode' );
				if ( isset( $_POST['country'] )  && $_POST['country'] == 'on' )  array_push( $address_fields, 'country' );

				$address_fields = serialize( $address_fields );
			}
			else {
				$address_fields = serialize( array( 'none' ) );
			}

			// format expiration date for db
			$expires = ( isset( $_POST['expires'] ) && $_POST['expires'] == 'on' ) ? '1' : '0';
			$year    = absint( $_POST['year'] );
			$month   = absint( $_POST['month'] );
			$day     = absint( $_POST['day'] );
			$hour    = absint( $_POST['hour'] );
			$minutes = absint( $_POST['minutes'] );

			if ( $expires == '1' ) {
				// force dates to be rational (ex: converts Jan 45 to Feb 14)
				$timestamp       = mktime( $hour, $minutes, 0, $month, $day, $year );
				$year            = date( 'Y', $timestamp );
				$month           = date( 'm', $timestamp );
				$day             = date( 'd', $timestamp );
				$hour            = date( 'H', $timestamp );
				$minutes         = date( 'i', $timestamp );
				$expiration_date = $year . '-' . $month . '-' . $day . ' ' . $hour . ':' . $minutes;
			}
			else {
				$expiration_date = '0000-00-00 00:00';
			}

			// prepare db query
			$sql = "
				UPDATE $db_petitions
				SET `petition_title` = '$petition_title', `petition_email` = '$petition_email', `petition_subject` = '$petition_subject',
					`petition_greeting` = '$petition_greeting',`petition_message` = '$petition_message', `address_fields` = '$address_fields', 
					`expires` = '$expires', `expiration_date` = '$expiration_date', `has_signature_goal` = '$has_signature_goal', 
					`signature_goal` = '$signature_goal', `send_email` = '$send_email', `twitter_message` = '$twitter_message', 
					`confirm` = '$confirm', `display_email_optin` = '$display_email_optin', `email_optin_label` = '$email_optin_label',
					`display_custom_field` = '$display_custom_field', `custom_field_label` = '$custom_field_label'
				WHERE `id` = '$id'
			";
			$wpdb->query( $sql );

			// set up default form values
			$nonce  = 'dk_speakup-update_petition' . $id;
			$action = 'update';

			// set up options for page display
			$page_title     = __( 'Edit New Email Petition', 'dk_speakup' );
			$message_update = __( 'Petition updated.' );
			$button_text    = __( 'Update Petition', 'dk_speakup' );
			$address_fields = unserialize( $address_fields );

			// delete transients so changes take immediate effect
			dk_speakup_delete_transients();

			break;

		// show blank form for adding a new petition
		default :
			// set up default form values
			$petition_title       = '';
			$petition_email       = '';
			$petition_subject     = '';
			$petition_greeting    = '';
			$petition_message     = '';
			$twitter_message      = '';
			$confirm              = '0';
			$has_signature_goal   = '0';
			$signature_goal       = '';
			$expires              = '0';
			$address_fields       = array();
			$display_custom_field = '0';
			$custom_field_label   = '';
			$display_email_optin  = '0';
			$email_optin_label    = __( 'Add me to your mailing list', 'dk_speakup' );
			$send_email           = '1';
			$month                = date( 'm', $next_week );
			$day                  = date( 'd', $next_week );
			$year                 = date( 'Y', $next_week );
			$hour                 = '16';
			$minutes              = '20';
			$nonce                = 'dk_speakup-create_petition';
			$action               = 'create';

			// set up strings for page display
			$page_title  = __( 'Add New Email Petition', 'dk_speakup' );
			$button_text = __( 'Create Petition', 'dk_speakup' );
	}
	// display the form
	include_once( dirname( __FILE__ ) . '/admin-edit-view.php' );
}

?>