<?php

// display plugin Settings page
function dk_speakup_settings_page() {
	// check security: ensure user has authority
	if ( !current_user_can( 'manage_options' ) ) wp_die( 'Insufficient privileges: You need to be an administrator to do that.' );

	$options = get_option( 'dk_speakup_options' );
	$page_title =  __( 'Email Petitions Settings', 'dk_speakup' );
	$action = isset( $_REQUEST['action'] ) ? $_REQUEST['action'] : '';
	$message_update = '';

	switch( $action ) {
		case 'update' :
			// security: ensure user has intention
			check_admin_referer( 'dk_speakup-update_settings' );

			$allowed_tags = array(
				'a'      => array( 'href' => array(),'title' => array() ),
				'em'     => array(),
				'strong' => array(),
				'p'      => array()
			);

			// prepare signature columns array for storage
			$sig_columns = array();
			if ( isset( $_POST['sig_city'] ) && $_POST['sig_city'] == 'on' )         array_push( $sig_columns, 'sig_city' );
			if ( isset( $_POST['sig_state'] ) && $_POST['sig_state'] == 'on' )       array_push( $sig_columns, 'sig_state' );
			if ( isset( $_POST['sig_postcode'] ) && $_POST['sig_postcode'] == 'on' ) array_push( $sig_columns, 'sig_postcode' );
			if ( isset( $_POST['sig_country'] ) && $_POST['sig_country'] == 'on' )   array_push( $sig_columns, 'sig_country' );
			if ( isset( $_POST['sig_custom'] ) && $_POST['sig_custom'] == 'on' )     array_push( $sig_columns, 'sig_custom' );
			if ( isset( $_POST['sig_date'] ) && $_POST['sig_date'] == 'on' )         array_push( $sig_columns, 'sig_date' );
			$signaturelist_columns = serialize( $sig_columns );

			$options = array(
				'petitions_rows'         => absint( $_POST['petitions_rows'] ),
				'signatures_rows'        => absint( $_POST['signatures_rows'] ),
				'petition_theme'         => $_POST['petition_theme'],
				'button_text'            => esc_html( stripslashes( $_POST['button_text'] ) ),
				'expiration_message'     => esc_html( stripslashes( $_POST['expiration_message'] ) ),
				'success_message'        => wp_kses( stripslashes( $_POST['success_message'] ), $allowed_tags ),
				'already_signed_message' => esc_html( stripslashes( $_POST['already_signed_message'] ) ),
				'share_message'          => esc_html( stripslashes( $_POST['share_message'] ) ),
				'confirm_subject'        => esc_html( $_POST['confirm_subject'] ),
				'confirm_message'        => strip_tags( stripslashes( $_POST['confirm_message'] ) ),
				'confirm_email'          => stripslashes( $_POST['confirm_email'] ),
				'optin_default'          => $_POST['optin_default'],
				'display_count'          => $_POST['display_count'],
				'signaturelist_header'   => esc_html( stripslashes( $_POST['signaturelist_header'] ) ),
				'signaturelist_rows'     => absint( $_POST['signaturelist_rows'] ),
				'signaturelist_columns'  => $signaturelist_columns
			);
			update_option( 'dk_speakup_options', $options );

			// set up form values
			$petitions_rows         = $options['petitions_rows'];
			$signatures_rows        = $options['signatures_rows'];
			$petition_theme         = $options['petition_theme'];
			$button_text            = $options['button_text'];
			$expiration_message     = $options['expiration_message'];
			$success_message        = $options['success_message'];
			$already_signed_message = $options['already_signed_message'];
			$share_message          = $options['share_message'];
			$confirm_subject        = $options['confirm_subject'];
			$confirm_message        = $options['confirm_message'];
			$confirm_email          = $options['confirm_email'];
			$signaturelist_header   = $options['signaturelist_header'];
			$signaturelist_rows     = $options['signaturelist_rows'];
			$optin                  = $options['optin_default'];
			$display_count          = $options['display_count'];
			$nonce                  = 'dk_speakup-update_settings';
			$action                 = 'update';
			$message_update         = __( 'Settings updated.', 'dk_speakup' );

			$sig_columns  = unserialize( $options['signaturelist_columns'] );
			$sig_city     = ( in_array( 'sig_city', $sig_columns ) ) ? 1 : 0;
			$sig_state    = ( in_array( 'sig_state', $sig_columns ) ) ? 1 : 0;
			$sig_postcode = ( in_array( 'sig_postcode', $sig_columns ) ) ? 1 : 0;
			$sig_country  = ( in_array( 'sig_country', $sig_columns ) ) ? 1 : 0;
			$sig_custom   = ( in_array( 'sig_custom', $sig_columns ) ) ? 1 : 0;
			$sig_date     = ( in_array( 'sig_date', $sig_columns ) ) ? 1 : 0;

			// delete transients so changes take immediate effect
			dk_speakup_delete_transients();

			break;

		default :
			// set up form values
			$petitions_rows         = $options['petitions_rows'];
			$signatures_rows        = $options['signatures_rows'];
			$petition_theme         = $options['petition_theme'];
			$button_text            = $options['button_text'];
			$expiration_message     = $options['expiration_message'];
			$success_message        = $options['success_message'];
			$already_signed_message = $options['already_signed_message'];
			$share_message          = $options['share_message'];
			$confirm_subject        = $options['confirm_subject'];
			$confirm_message        = $options['confirm_message'];
			$confirm_email          = $options['confirm_email'];
			$signaturelist_header   = $options['signaturelist_header'];
			$signaturelist_rows     = $options['signaturelist_rows'];
			$optin                  = $options['optin_default'];
			$display_count          = $options['display_count'];
			$nonce                  = 'dk_speakup-update_settings';
			$action                 = 'update';
			
			$sig_columns  = unserialize( $options['signaturelist_columns'] );
			$sig_city     = ( in_array( 'sig_city', $sig_columns ) ) ? 1 : 0;
			$sig_state    = ( in_array( 'sig_state', $sig_columns ) ) ? 1 : 0;
			$sig_postcode = ( in_array( 'sig_postcode', $sig_columns ) ) ? 1 : 0;
			$sig_country  = ( in_array( 'sig_country', $sig_columns ) ) ? 1 : 0;
			$sig_custom   = ( in_array( 'sig_custom', $sig_columns ) ) ? 1 : 0;
			$sig_date     = ( in_array( 'sig_date', $sig_columns ) ) ? 1 : 0;
	}

	include_once( dirname( __FILE__ ) . '/admin-settings-view.php' );
}

?>