<?php

function dk_speakup_signatures_page() {
	// check security: ensure user has authority
	if ( !current_user_can( 'publish_posts' ) ) wp_die( __('Insufficient privileges: You need to be an editor to do that.', 'dk_speakup') );

	global $wpdb, $db_petitions, $db_signatures;
	$action = isset( $_REQUEST['action'] ) ? $_REQUEST['action'] : '';
	$pid = isset( $_REQUEST['pid'] ) ? $_REQUEST['pid'] : ''; // petition id
	$sid = isset( $_REQUEST['sid'] ) ? $_REQUEST['sid'] : ''; // signature id
	$options = get_option( 'dk_speakup_options' );

	// set up default page display strings
	$page_title = __( 'Signatures', 'dk_speakup' );
	$message_update = '';

	// set variables for paged record display and for limit values in db query
	$paged = isset( $_REQUEST['paged'] ) ? $_REQUEST['paged'] : '1';
	$total_pages = isset ( $_REQUEST['total_pages'] ) ? $_REQUEST['total_pages'] : '1';
	$current_page = dk_speakup_current_paged( $paged, $total_pages );
	$query_limit = $options['signatures_rows'];
	$query_start = ( $current_page * $query_limit ) - $query_limit;

	switch ( $action ) {
		case 'delete' :
			// security: ensure user has intention
			check_admin_referer( 'dk_speakup-delete_signature' . $sid );

			// delete petition from the db
			$sql_delete = "
				DELETE FROM `$db_signatures`
				WHERE `id` = '$sid'
			";
			$wpdb->query( $sql_delete );

			// count number of signatures in db
			// add WHERE clause if deleting from a view of only one petition
			$where = ( $pid != '' ) ? "WHERE `petitions_id` = '$pid'" : '';
			$sql_get_count = "
				SELECT `id`
				FROM `$db_signatures` $where
			";
			$results_get_count = $wpdb->get_results( $sql_get_count );
			$count = count( $results_get_count );

			// prepare db query to display remaining signatures
			// add AND clause to WHERE statement if pid is set (when viewing only signatures from a specific petition)
			$which_petition = ( $pid != '' ) ? "AND $db_signatures.petitions_id = '$pid'" : '';
			$sql_select = "
				SELECT $db_signatures.id, $db_signatures.first_name, $db_signatures.last_name, 
					$db_signatures.email, $db_signatures.date, $db_signatures.confirmed,
					$db_signatures.email_optin, $db_petitions.petition_title
				FROM `$db_signatures`, `$db_petitions`
				WHERE $db_signatures.petitions_id = $db_petitions.id $which_petition
				ORDER BY $db_signatures.id DESC LIMIT $query_start, $query_limit
			";
			$results = $wpdb->get_results( $sql_select );

			// variables used in table html
			// set up values for the table label ie: All Signatures (36)
			if ( $count == 0 ) {
				$petition = '';
			}
			elseif ( $pid != '' ) {
				$petition = $results[0]->petition_title;
			}
			else {
				$petition = __( 'All Signatures', 'dk_speakup' );
			}
			$table_label = esc_html( $petition ) . ' <span class="count">(' . $count . ')</span>';
			$message_update = __( 'Signature deleted.', 'dk_speakup' );
			$base_url = site_url( 'wp-admin/admin.php?page=dk_speakup_signatures&action=petition&pid=' . $pid );
			break;

		case 'petition' :
			// count number of signatures in db
			$sql_get_count = "
				SELECT `id`
				FROM `$db_signatures`
				WHERE `petitions_id` = '$pid'
			";
			$results_get_count = $wpdb->get_results( $sql_get_count );
			$count = count( $results_get_count );

			// query signatures for the petition specified in $pid
			$sql = "
				SELECT $db_signatures.id, $db_signatures.first_name, $db_signatures.last_name,
					$db_signatures.email, $db_signatures.date, $db_signatures.confirmed,
					$db_signatures.email_optin, $db_petitions.petition_title
				FROM `$db_signatures`, `$db_petitions`
				WHERE $db_signatures.petitions_id = $db_petitions.id AND $db_signatures.petitions_id = '$pid'
				ORDER BY $db_signatures.id DESC LIMIT $query_start, $query_limit
			";
			$results = $wpdb->get_results( $sql );

			// variables used in table html
			$table_label   = ( count( $results ) > 0 ) ? esc_html( $results[0]->petition_title ) . ' <span class="count">(' . $count . ')</span>' : __( 'Petition', 'dk_speakup' ) . ' ' . $pid . ' <span class="count">(0)</span>';
			$base_url      = site_url( 'wp-admin/admin.php?page=dk_speakup_signatures&action=petition&pid=' . $pid );
			break;

		case 'reconfirm' :
			check_admin_referer( 'dk_speakup-resend_confirmations' . $pid );
			// query petition data needed to send email
			$sql_reconfirm = "
				SELECT `first_name`, `last_name`, `email`, `confirmation_code`
				FROM $db_signatures
				WHERE `petitions_id` = '$pid' AND `confirmed` = '0'
			";
			$reconfirm = $wpdb->get_results( $sql_reconfirm );

			foreach( $reconfirm as $confirm ) {
				$home_url             = home_url();
				$first_name           = $confirm->first_name;
				$last_name            = $confirm->last_name;
				$email                = $confirm->email;
				$confirmation_code    = $confirm->confirmation_code;
				$confirmation_url     = $home_url . '?dkspeakupconfirm=' . $confirmation_code;
				$confirmation_message = $options['confirm_message'];
				$confirmation_subject = $options['confirm_subject'];
				$confirmation_headers = "From: " . $options['confirm_email'] . "\r\n";

				// ensure confirmation link is included in email, even if user left it out
				if ( strpos( $confirmation_message, '%confirmation_link%' ) == false ) {
					$confirmation_message = $confirmation_message .  "\r\n\r\n" . $confirmation_url;
				}
				// check for user-supplied variables
				$confirm_search       = array( '%first_name%', '%last_name%', '%confirmation_link%' );
				$confirm_replace      = array( $first_name, $last_name, $confirmation_url );
				$confirmation_message = str_replace( $confirm_search, $confirm_replace, $confirmation_message );

				// send confirmation email
				wp_mail( $email, $confirmation_subject, $confirmation_message, $confirmation_headers );
			}
			
			// count number of signatures in db
			$sql_get_count = "
				SELECT `id`
				FROM `$db_signatures`
				WHERE `petitions_id` = '$pid'
			";
			$results_get_count = $wpdb->get_results( $sql_get_count );
			$count = count( $results_get_count );

			// query signatures for the petition specified in $pid
			$sql = "
				SELECT $db_signatures.id, $db_signatures.first_name, $db_signatures.last_name,
					$db_signatures.email, $db_signatures.date, $db_signatures.confirmed,
					$db_signatures.email_optin, $db_petitions.petition_title
				FROM `$db_signatures`, `$db_petitions`
				WHERE $db_signatures.petitions_id = $db_petitions.id AND $db_signatures.petitions_id = '$pid'
				ORDER BY $db_signatures.id DESC LIMIT $query_start, $query_limit
			";
			$results = $wpdb->get_results( $sql );

			// variables used in table html
			$table_label    = ( count( $results ) > 0 ) ? esc_html( $results[0]->petition_title ) . ' <span class="count">(' . $count . ')</span>' : __( 'Petition', 'dk_speakup' ) . ' ' . $pid . ' <span class="count">(0)</span>';
			$base_url       = site_url( 'wp-admin/admin.php?page=dk_speakup_signatures&action=petition&pid=' . $pid );
			$message_update = __( 'Confirmation emails sent.', 'dk_speakup' );
			break;

		default :
			// get total number of signatures in db
			$sql_get_count = "
				SELECT `id`
				FROM `$db_signatures`
			";
			$results_get_count = $wpdb->get_results( $sql_get_count );
			$count = count( $results_get_count );

			// select the signatures for display
			$sql = "
				SELECT $db_signatures.id, $db_signatures.first_name, $db_signatures.last_name,
					$db_signatures.email, $db_signatures.date, $db_signatures.confirmed,
					$db_signatures.email_optin, $db_petitions.petition_title
				FROM `$db_signatures`, `$db_petitions`
				WHERE $db_signatures.petitions_id = $db_petitions.id
				ORDER BY $db_signatures.id DESC LIMIT $query_start, $query_limit
			";
			$results = $wpdb->get_results( $sql );

			// variables used in table html
			$table_label = __( 'All Signatures', 'dk_speakup' ) . ' <span class="count">(' . $count . ')</span>';
			$base_url = site_url( 'wp-admin/admin.php?page=dk_speakup_signatures' );
	}

	// get list of petitions to populate select box navigation
	$sql_petitons_list = "
		SELECT id, petition_title
		FROM `$db_petitions`
	";
	$petitions_list = $wpdb->get_results( $sql_petitons_list );

	// Set up URLs fo 'Download as CSV' and 'Resend confirmations' buttons
	// Always show buttons when we are only viewing signatures from a single petition...
	// Should work if only one petition exists or if user has intentionally selected to view a single petition's signatures.
	// The if statement here determines if we are viewing signatures from only a single petition.
	// A false result means we're viewing multiple petitions and the buttons will be hidden
	if ( count( $petitions_list ) == 1 || $pid != '' ) {
		// if $pid (petition id) wasn't sent through the URL, then create it from the query
		if ( $pid == '' ) {
			$pid = $petitions_list[0]->id;
		}
		$csv_url = site_url( 'wp-admin/admin.php?page=dk_speakup_signatures&action=petition&pid=' . $pid );
		$reconfirm_url = site_url( 'wp-admin/admin.php?page=dk_speakup_signatures&action=reconfirm&pid=' . $pid );
	}

	// display the Signatures table
	include_once( dirname( __FILE__ ) . '/admin-signatures-view.php' );
}

?>