<?php

// create admin menus
add_action( 'admin_menu', 'dk_speakup_create_menus' );
function dk_speakup_create_menus() {
	// create Petitions page
	add_menu_page( __( 'Email Petitions', 'dk_speakup' ), __( 'Email Petitions', 'dk_speakup' ), 'publish_posts', 'dk_speakup', 'dk_speakup_petitions_page', plugins_url( 'speakup-email-petitions/images/blank.png' ) );
	// create Add New page
	add_submenu_page( 'dk_speakup', __( 'Add New' ), __( 'Add New', 'dk_speakup' ), 'publish_posts', 'dk_speakup_edit', 'dk_speakup_edit_page' );
	// create Signatures page
	add_submenu_page( 'dk_speakup', __( 'Signatures', 'dk_speakup' ), __( 'Signatures', 'dk_speakup' ), 'publish_posts', 'dk_speakup_signatures', 'dk_speakup_signatures_page' );
	// create Settings page
	add_submenu_page( 'dk_speakup', __( 'Email Petitions Settings', 'dk_speakup' ), __( 'Settings', 'dk_speakup' ), 'manage_options', 'dk_speakup_settings', 'dk_speakup_settings_page' );
}

// display custom menu icon
add_action( 'admin_head', 'dk_speakup_menu_icon' );
function dk_speakup_menu_icon() {
	echo '
		<style type="text/css">
			#toplevel_page_dk_speakup .wp-menu-image {
				background: url(' . plugins_url( "speakup-email-petitions/images/icon-emailpetitions-16.png" ) . ') no-repeat 6px 7px !important;
			}
			#toplevel_page_dk_speakup:hover .wp-menu-image, #toplevel_page_dk_speakup.wp-has-current-submenu .wp-menu-image {
				background-position: 6px -17px !important;
			}
		</style>
	';
}

// load JavaScript for use on admin pages
add_action( 'admin_print_scripts', 'dk_speakup_admin_js' );
function dk_speakup_admin_js() {
	global $parent_file;

	// make sure scripts load only on this plugin's admin pages
	if ( $parent_file == 'dk_speakup' ) {
		wp_enqueue_script( 'dk_speakup_admin_js', plugins_url( 'speakup-email-petitions/js/admin.js' ), array( 'jquery' ) );
		wp_enqueue_script( 'post', admin_url( 'js/post.js' ), 'jquery' );
	}
}

// load CSS for use on admin pages
add_action( 'admin_print_styles', 'dk_speakup_admin_css' );
function dk_speakup_admin_css() {
	global $parent_file;

	// make sure styles load only on this plugin's admin pages
	if ( $parent_file == 'dk_speakup' ) {
		wp_enqueue_style( 'dk_speakup_admin_css', plugins_url( 'speakup-email-petitions/css/admin.css' ) );
	}
}

/**
 * Handle public petition form submissions
 * 
 * Petition form is submitted via AJAX
 * Then we determine whether to send a request for email confirmation
 * or to go ahead and send out the petition message email.
 * Then we add the signature to DB
 */
add_action( 'wp_ajax_dk_speakup_sendmail', 'dk_speakup_sendmail' );
add_action( 'wp_ajax_nopriv_dk_speakup_sendmail', 'dk_speakup_sendmail' );
function dk_speakup_sendmail() {
	global $wpdb, $db_petitions, $db_signatures;
	$options = get_option( 'dk_speakup_options' );

	$petitions_id      = absint( $_POST['id'] );
	$first_name        = esc_html( stripslashes( $_POST['first_name'] ) );
	$last_name         = esc_html( stripslashes( $_POST['last_name'] ) );
	$email             = esc_html( stripslashes( $_POST['email'] ) );
	$street            = ( isset( $_POST['street'] ) ) ? esc_html( stripslashes( $_POST['street'] ) ) : '';
	$city              = ( isset( $_POST['city'] ) ) ? esc_html( stripslashes( $_POST['city'] ) ) : '';
	$state             = ( isset( $_POST['state'] ) ) ? esc_html( stripslashes( $_POST['state'] ) ) : '';
	$postcode          = ( isset( $_POST['postcode'] ) ) ? esc_html( stripslashes( $_POST['postcode'] ) ) : '';
	$country           = ( isset( $_POST['country'] ) ) ? esc_html( stripslashes( $_POST['country'] ) ) : '';
	$custom_field      = ( isset( $_POST['custom_field'] ) ) ? esc_html( stripslashes( $_POST['custom_field'] ) ) : '';
	$optin             = ( isset( $_POST['optin'] ) && $_POST['optin'] == 'on' ) ? '1' : '0';
	$date              = current_time( 'mysql', 0 );
	$email_headers     = "From: " . $first_name . " " . $last_name . " <" . $email . ">" . "\r\n";
	$confirmation_code = '';
	$confirmed         = '';

	// query to determine if submitted email address has already been used on this petition
	$sql_check = "
		SELECT `id`
		FROM $db_signatures
		WHERE `email` = '$email' AND `petitions_id` = '$petitions_id'
	";
	$results = $wpdb->get_row( $sql_check );

	// if email has already been used, disply error message
	if ( count( $results ) ) {
		echo $options['already_signed_message'];
	}
	// otherwise insert new signature in db, send email, and display thank you message
	else {
		// query petition data needed to send email
		$sql_select = "
			SELECT `petition_title`, `petition_email`, `petition_subject`, `petition_greeting`, 
				`petition_message`, `send_email`, `confirm`
			FROM $db_petitions
			WHERE `id` = '$petitions_id'
		";
		$petition = $wpdb->get_row( $sql_select );

		// if petition requires email confirmation, send confirmation message
		if ( $petition->confirm == '1' ) {

			// set signature to unconfirmed
			$confirmed = '0';

			// generate confirmation code and construct URL
			$confirmation_code = substr( md5( uniqid() ), 0, 16 );
			$confirmation_url = home_url() . '?dkspeakupconfirm=' . $confirmation_code;

			// set up the confirmation message based on option entered on settings page
			$confirmation_message = $options['confirm_message'];

			// ensure confirmation link is included in email, even if user left it out
			if ( strpos( $confirmation_message, '%confirmation_link%' ) == false ) {
				$confirmation_message = $confirmation_message .  "\r\n\r\n" . $confirmation_url;
			}
			// check for user-supplied variables
			$petition_title       = $petition->petition_title;
			$confirm_search       = array( '%first_name%', '%last_name%', '%petition_title%', '%confirmation_link%' );
			$confirm_replace      = array( $first_name, $last_name, $petition_title, $confirmation_url );
			$confirmation_message = str_replace( $confirm_search, $confirm_replace, $confirmation_message );

			$confirmation_subject = $options['confirm_subject'];
			$confirmation_headers = "From: " . $options['confirm_email'] . "\r\n";

			// send confirmation email
			wp_mail( $email, $confirmation_subject, $confirmation_message, $confirmation_headers );
		}
		// else, send the petition email to target address
		else {
			if ( $petition->send_email == '1' ) {
				// construct the email message body (adding the signature)
				$greeting = $petition->petition_greeting . "\r\n\r\n";
				// add newline after address fileds only if the fields exist
				$street    = ( $street != '' ) ? $street . "\r\n" : '';
				// construct city / state line in format City, ST if both values are present
				// if only state is present, put state on it's own line
				// ele put city on its own line
				if ( $city != '' && $state != '' ) {
					$city = $city . ", " . $state . "\r\n";
					$state = '';
				}
				elseif ( $city == '' && $state != '' ) {
					$state = ( $state != '' ) ? $state . "\r\n" : '';
				}
				else {
					$city = ( $city != '' ) ? $city . "\r\n" : '';
				}
				$postcode     = ( $postcode != '' ) ? $postcode . "\r\n" : '';
				$country      = ( $country != '' ) ? $country . "\r\n" : '';
				$address      = $street . $city . $state . $postcode . $country;
				$custom_field = "\r\n" . $custom_field;
				$signature    = "\r\n\r\n--\r\n" . $first_name . " " . $last_name . "\r\n" . $email . "\r\n"  . $address . $custom_field . "\r\n";
				$message      = html_entity_decode( $greeting . $petition->petition_message . $signature, ENT_QUOTES );
				// send the petition email
				wp_mail( $petition->petition_email, $petition->petition_subject, $message, $email_headers );
			}
		}

		// add signature to the signatures table
		$sql_insert = "
			INSERT INTO $db_signatures ( 
				`petitions_id`, `first_name`, `last_name`, `email`, `date`, `confirmation_code`, 
				`confirmed`, `email_optin`, `street_address`, `city`, `state`, `postcode`, `country`, `custom_field`
			)
			VALUES ( 
				'$petitions_id', '$first_name', '$last_name', '$email', '$date', '$confirmation_code', 
				'$confirmed', '$optin', '$street', '$city', '$state', '$postcode', '$country', '$custom_field'
			)
		";
		$wpdb->query( $sql_insert );

		// display success message
		$success_message = $options['success_message'];
		$success_message = str_replace( '%first_name%', $first_name, $success_message );
		$success_message = str_replace( '%last_name%', $last_name, $success_message );
		echo $success_message;
	}

	die();
}

?>