<?php

// plugin installation routine
function dk_speakup_install() {

	global $wpdb, $db_petitions, $db_signatures, $dk_speakup_version;

	dk_speakup_translate();

	$sql_create_tables = "
		CREATE TABLE `$db_petitions` (
			`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
			`petition_title` TEXT CHARACTER SET utf8 NOT NULL,
			`petition_email` VARCHAR(300) CHARACTER SET utf8 NOT NULL,
			`petition_subject` VARCHAR(200) CHARACTER SET utf8 NOT NULL,
			`petition_greeting` VARCHAR(200) CHARACTER SET utf8 NOT NULL,
			`petition_message` LONGTEXT CHARACTER SET utf8 NOT NULL,
			`address_fields` VARCHAR(200) CHARACTER SET utf8 NOT NULL,
			`expires` CHAR(1) BINARY NOT NULL,
			`expiration_date` DATETIME NOT NULL,
			`created_date` DATETIME NOT NULL,
			`has_signature_goal` CHAR(1) BINARY NOT NULL,
			`signature_goal` INT(11) NOT NULL,
			`send_email` CHAR(1) BINARY NOT NULL,
			`twitter_message` VARCHAR(120) CHARACTER SET utf8 NOT NULL,
			`confirm` CHAR(1) BINARY NOT NULL,
			`display_custom_field` CHAR(1) BINARY NOT NULL,
			`custom_field_label` VARCHAR(200) CHARACTER SET utf8 NOT NULL,
			`display_email_optin` CHAR(1) BINARY NOT NULL,
			`email_optin_label` VARCHAR(200) CHARACTER SET utf8 NOT NULL,
			UNIQUE KEY  (`id`)
		);
		CREATE TABLE `$db_signatures` (
			`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
			`petitions_id` BIGINT(20) NOT NULL,
			`first_name` VARCHAR(200) CHARACTER SET utf8 NOT NULL,
			`last_name` VARCHAR(200) CHARACTER SET utf8 NOT NULL,
			`email` VARCHAR(200) CHARACTER SET utf8 NOT NULL,
			`street_address` VARCHAR(200) CHARACTER SET utf8 NOT NULL,
			`city` VARCHAR(200) CHARACTER SET utf8 NOT NULL,
			`state` VARCHAR(200) CHARACTER SET utf8 NOT NULL,
			`postcode` VARCHAR(200) CHARACTER SET utf8 NOT NULL,
			`country` VARCHAR(200) CHARACTER SET utf8 NOT NULL,
			`custom_field` VARCHAR(200) CHARACTER SET utf8 NOT NULL,
			`email_optin` CHAR(1) BINARY NOT NULL,
			`date` DATETIME NOT NULL,
			`confirmation_code` VARCHAR(32) NOT NULL,
			`confirmed` CHAR(1) BINARY NOT NULL,
			UNIQUE KEY  (`id`)
		);";

	// create database tables
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $sql_create_tables );

	// set default options
	$options = array(
		"petitions_rows" => "20",
		"signatures_rows" => "50",
		"petition_theme" => "standard",
		"petition_header" => __( "SIGN THE PETITION", "dk_speakup" ),
		"button_text" => __( "SIGN NOW", "dk_speakup" ),
		"expiration_message" => __( "This petition is now closed.", "dk_speakup" ),
		"success_message" => "<strong>" . __( "Thank you", "dk_speakup" ) . ", %first_name%.</strong><p>" . __( "Your signature has been added.", "dk_speakup" ) . "</p>",
		"already_signed_message" => __( "This petition has already been signed using your email address.", "dk_speakup"),
		"share_message" => __( "Share this with your friends:", "dk_speakup" ),
		"confirm_subject" => __( "Please confirm your email address", "dk_speakup" ),
		"confirm_message" => __( "Please confirm your email address by clicking the link below:", "dk_speakup" ) . "\r\n%confirmation_link%",
		"confirm_email" => get_bloginfo( "name" ) . " <" . get_bloginfo( "admin_email" ) . ">",
		"optin_default" => "unchecked",
		"display_count" => "1",
		"signaturelist_header" => __( "Latest Signatures", "dk_speakup" ),
		"signaturelist_rows" => "50",
		"signaturelist_columns" => serialize( array( "sig_date" ) )
	);
	// add plugin options to wp_options table
	add_option( 'dk_speakup_options', $options );
	add_option( 'dk_speakup_version', $dk_speakup_version );
}

// run plugin update script if needed
add_action( 'plugins_loaded', 'dk_speakup_update' );
function dk_speakup_update() {

	global $wpdb, $db_petitions, $db_signatures, $dk_speakup_version;
	$installed_version = get_option( 'dk_speakup_version' );

	// Database changes to accomodate addition of granular address fields in version 1.6
	if ( $installed_version < 1.6 ) {
		// change old 'address' column name to 'street_address' in signatures table
		$sql_update = "
			ALTER TABLE $db_signatures
			CHANGE address street_address VARCHAR(200) CHARACTER SET utf8 NOT NULL
		;";
		$wpdb->query( $sql_update );

		// drop display_address column in petitions table
		$sql_update = "
			ALTER TABLE $db_petitions
			CHANGE display_address address_fields VARCHAR(200) CHARACTER SET utf8 NOT NULL
		;";
		$wpdb->query( $sql_update );

		// make existing petitions that were set to display the address field now display the new street field
		$address_fields = serialize( array( 'street' ) );
		$sql_update = "
			UPDATE $db_petitions
			SET `address_fields` = '$address_fields'
			WHERE `address_fields` = '1'
		;";
		$wpdb->query( $sql_update );
	}

	// Bug fix: address fields
	if ( $installed_version < 1.7 ) {
		// make existing petitions that were NOT set to display the address field contain a serialized array
		$address_fields = serialize( array( 'none' ) );
		$sql_update = "
			UPDATE $db_petitions
			SET `address_fields` = '$address_fields'
			WHERE `address_fields` = '0'
		;";
		$wpdb->query( $sql_update );

		$sql_update = "
			UPDATE $db_petitions
			SET `address_fields` = '$address_fields'
			WHERE `address_fields` = 'Array'
		;";
		$wpdb->query( $sql_update );
	}

	if ( $installed_version != $dk_speakup_version ) {

		// create database tables and options
		dk_speakup_install();

		$options = get_option( 'dk_speakup_options' );

		// options added after initial release
		if ( !array_key_exists( 'confirm_subject', $options ) ) {
			$options['confirm_subject'] = __( 'Please confirm your email address', 'dk_speakup' );
		}
		if ( !array_key_exists( 'confirm_message', $options ) ) {
			$options['confirm_message'] = __( 'Please confirm your email address by clicking the link below:', 'dk_speakup' ) . "\r\n%confirmation_link%";
		}
		if ( !array_key_exists( 'confirm_email', $options ) ) {
			$options['confirm_email'] = get_bloginfo( 'name' ) . ' <' . get_bloginfo( 'admin_email' ) . '>';
		}
		if ( !array_key_exists( 'signaturelist_header', $options ) ) {
			$options['signaturelist_header'] = __( 'Latest Signatures', 'dk_speakup' );
		}
		if ( !array_key_exists( 'signaturelist_rows', $options ) ) {
			$options['signaturelist_rows'] = '50';
		}
		if ( !array_key_exists( 'optin_default', $options ) ) {
			$options['optin_default'] = 'unchecked';
		}
		if ( !array_key_exists( 'display_count', $options ) ) {
			$options['display_count'] = '1';
		}
		if ( !array_key_exists( 'signaturelist_columns', $options ) ) {
			$options['signaturelist_columns'] = serialize( array( 'sig_date' ) );
		}
		update_option( 'dk_speakup_options', $options );
	}

	// update plugin version tag in db
	if ( $installed_version != $dk_speakup_version ) {
		update_option( 'dk_speakup_version', $dk_speakup_version );
	}
}

?>