<?php

function dk_speakup_twiter_encode( $tweet ) {
	$tweet = str_replace( "&#039;", "'", $tweet );
	$tweet = str_replace( "#", urlencode( "#" ), $tweet );
	return $tweet;
}

/**
 * Queries data needed for public display of petition forms
 * Returns query resuts as an array object
 *
 * @param $id (int) the unique ID of the petition to be queried
 * @param $expiration (int) time in seconds that the query data should be cached
 */
function dk_speakup_get_petition( $id, $expiration = 30 ) {

	global $wpdb, $db_petitions, $db_signatures;

	// construct a transient name that will be unique for each petition
	$transient_name = 'dk_speakup_petition_' . $id;
	
	// check if query data is already stored as a transient
	$petition = get_transient( $transient_name );

	// if transient data doesn't exist or has expired,
	// run the database query and store results as a new transient
	if ( $petition === false ) {
		$sql = "
			SELECT $db_petitions.*, COUNT( $db_signatures.id ) AS 'signatures'
			FROM $db_petitions
			LEFT JOIN $db_signatures
				ON $db_petitions.id = $db_signatures.petitions_id
				AND ( $db_signatures.confirmed = '' OR $db_signatures.confirmed = '1' )
			WHERE $db_petitions.id = $id
			GROUP BY $db_petitions.id
		";
		$petition = $wpdb->get_row( $sql );
		// set transient if petition exists
		if ( !empty( $petition ) ) {
			set_transient( $transient_name, $petition, $expiration );
		}
	}

	return $petition;
}

/**
 * Queries signature data for public display of signatureslist shortcode
 * Returns query resuts as an array object
 *
 * @param $id (int) the unique ID of the petition whose signatures to be queried
 * @param $columns (array) the columns to be displayed
 * @param $limit (int) the number of signatures to display in the signaturelist - from settings page
 * @param $expiration (int) time in seconds that the query data should be cached
 */
function dk_speakup_get_signatureslist( $id, $columns, $limit, $expiration = 30 ) {

	global $wpdb, $db_signatures;

	// construct a transient name that will be unique for each petition
	$transient_name = 'dk_speakup_signatureslist_' . $id;
	
	// check if query data is already stored as a transient
	$signatureslist = get_transient( $transient_name );

	// if transient data doesn't exist or has expired,
	// run the database query and store results as a new transient
	if ( $signatureslist === false ) {

		// construct sql query that includes only the fields we need
		$sql_columns = 'first_name, last_name';
		if ( in_array( 'sig_city', $columns ) ) $sql_columns     .= ', city';
		if ( in_array( 'sig_state', $columns ) ) $sql_columns    .= ', state';
		if ( in_array( 'sig_postcode', $columns ) ) $sql_columns .= ', postcode';
		if ( in_array( 'sig_country', $columns ) ) $sql_columns  .= ', country';
		if ( in_array( 'sig_custom', $columns ) ) $sql_columns   .= ', custom_field';
		if ( in_array( 'sig_date', $columns ) ) $sql_columns     .= ', date';
		
		$sql = "
			SELECT $sql_columns
			FROM `$db_signatures`
			WHERE $db_signatures.petitions_id = $id AND $db_signatures.confirmed != '0'
			ORDER BY $db_signatures.date DESC
			$limit
		";
		$signatureslist = $wpdb->get_results( $sql );
		if ( !empty( $signatureslist ) ) {
			set_transient( $transient_name, $signatureslist, $expiration );
		}
	}

	return $signatureslist;
}

/**
 * Queries signature data for public display of signatureslist shortcode
 * Returns query resuts as an array object
 *
 * @param $id (int) the unique ID of the petition whose signatures to be queried
 * @param $expiration (int) time in seconds that the query data should be cached
 */
function dk_speakup_get_signatures_total( $id, $expiration = 30 ) {

	global $wpdb, $db_signatures;

	// construct a transient name that will be unique for each petition
	$transient_name = 'dk_speakup_signatures_total_' . $id;
	
	// check if query data is already stored as a transient
	$signatures_total = get_transient( $transient_name );

	// if transient data doesn't exist or has expired,
	// run the database query and store results as a new transient
	if ( $signatures_total === false ) {
		$sql = "
			SELECT $db_signatures.id
			FROM `$db_signatures`
			WHERE $db_signatures.petitions_id = $id AND $db_signatures.confirmed != '0'
		";
		$signatures_total = $wpdb->get_results( $sql );
		if ( !empty( $signatures_total ) ) {
			set_transient( $transient_name, $signatures_total, $expiration );
		}
	}

	return $signatures_total;
}

/**
 * Gets firstname, lastname and email for logged in users
 * to pre-populate fields in petition form
 */
function dk_speakup_get_userinfo() {
	$current_user = wp_get_current_user();

	if ( $current_user->ID != 0 ) {
		$firstname = $current_user -> user_firstname;
		$lastname  = $current_user -> user_lastname;
		$email     = $current_user -> user_email;
	} else {
		$firstname = '';
		$lastname  = '';
		$email     = '';
	}

	$userdata = array(
		'firstname' => $firstname,
		'lastname'  => $lastname,
		'email'     => $email
	);

	return $userdata;
}

/**
 * Constructs progress bar used on Petitions table page in the admin
 *
 * @param $goal (int) signatures goal
 * @param $signatures (int) number of signatures collected so far
 * @param $max_width (int) width of the outer progress bar div in pixels
 * @param $has_goal (bool) whether to display the goal progress bar
 * @param $widget (bool) whether to add widget-specific CSS classes
 */
function dk_speakup_public_goal_progress( $goal, $signatures, $max_width, $has_goal = 0, $widget = 0 ) {
	// determine how wide the progress bar should be
	$width_multiplier  = $max_width / 100;
	$percent_complete  = ( $goal != 0 ) ? floor( ( $signatures / $goal ) * 100 ) : 0;
	$progressbar_width = ( $percent_complete > 100 ) ? $max_width : floor( $percent_complete * $width_multiplier );

	// set up string to alter CSS class names for use in widgets
	$widget = ( $widget == 0 ) ? '' : 'widget-';

	// set progress bar color via CSS class
	if ( $percent_complete < 20 ) {
		$color_class = 'dk-speakup-' . $widget . 'progressbar-low';
	}
	elseif ( $percent_complete < 80 ) {
		$color_class = 'dk-speakup-' . $widget . 'progressbar-medium';
	}
	else {
		$color_class = 'dk-speakup-' . $widget . 'progressbar-complete';
	}

	// pluralize "signature"
	$sig_text = ( $signatures == 1 ) ? __( 'signature', 'dk_speakup' ) : __( 'signatures', 'dk_speakup' );

	// create HTML for signature count / progress bar display
	if ( $has_goal == 1 ) {
		// display signature count and progress bar
		$progressbar = '
			<div class="dk-speakup-' . $widget . 'progress-wrap">
				<div class="dk-speakup-' . $widget . 'signature-count"><span>' . number_format( $signatures ) . '</span> ' . $sig_text . '</div>
				<div class="dk-speakup-' . $widget . 'progress" style="width: ' . $max_width . 'px;">
					<div class="dk-speakup-' . $widget . 'progressbar ' . $color_class . '" style="width: ' . $progressbar_width . 'px;"></div>
				</div>
				<div class="dk-speakup-clear"></div>
			</div>
		';
	}
	else {
		// display only the signature count
		$progressbar = '
			<div class="dk-speakup-' . $widget . 'progress-wrap">
				<div class="dk-speakup-' . $widget . 'signature-count"><span>' . number_format( $signatures ) . '</span> ' . $sig_text . '</div>
				<div class="dk-speakup-clear"></div>
			</div>
		';
	}
	return $progressbar;
}

// capture requests from links clicked in confirmation emails
if ( isset( $_REQUEST['dkspeakupconfirm'] ) ) {
	add_action( 'template_redirect', 'dk_speakup_confirm_email' );
}
/**
 * Gets request variable passed from links clicked in confirmation emails
 * and check for match in signatures db table.
 * If match is found, set signature to confirmed and send petition email
 * Then display confirmation status message
 */
function dk_speakup_confirm_email() {

	global $wpdb;
	$db_petitions  = $wpdb->prefix . "dk_speakup_petitions";
	$db_signatures = $wpdb->prefix . "dk_speakup_signatures";

	// get the confirmation code from url
	$confirmation_code = $_REQUEST['dkspeakupconfirm'];

	// try to confirm the signature
	$confirmation_sql = "
		UPDATE $db_signatures
		SET `confirmed` = '1'
		WHERE `confirmation_code` = '$confirmation_code'
	";
	$confirmation_result = $wpdb->query( $confirmation_sql );

	// if a match for the conformation code exists,
	// show message and send out the petition email
	if ( $confirmation_result > 0 ) {
		// figure out which petition the signature we confirmed belongs to
		$signature_data = "
			SELECT petitions_id, first_name, last_name, email, street_address, city, state, postcode, country, custom_field
			FROM $db_signatures
			WHERE `confirmation_code` = '$confirmation_code' AND `confirmed` = '1'
		";
		$signature = $wpdb->get_row( $signature_data );

		// get the petition data needed to send email
		$petition_data = "
			SELECT `petition_email`, `petition_subject`, `petition_greeting`, `petition_message`, `send_email`, `confirm`
			FROM $db_petitions
			WHERE `id` = '$signature->petitions_id'
		";
		$petition = $wpdb->get_row( $petition_data );

		// if the "Don't send email" option was left unchecked...
		if ( $petition->send_email == '1' ) {
			// values from signatures table get used twice below, so need to convert them to PHP variables
			$first_name   = $signature->first_name;
			$last_name    = $signature->last_name;
			$email        = $signature->email;
			$street       = $signature->street_address;
			$city         = $signature->city;
			$state        = $signature->state;
			$postcode     = $signature->postcode;
			$country      = $signature->country;
			$custom_field = $signature->custom_field;

			// construct the petition email message
			$greeting = $petition->petition_greeting . "\r\n\r\n";
			$street   = ( $street != '' ) ? $street . "\r\n" : '';
			// construct city / state line in format City, ST if both values are present
			// if only state is present, put state on it's own line
			// ele put city on its own line
			if ( $city != '' && $state != '' ) {
				$city = $city . ", " . $state . "\r\n";
				$state = '';
			}
			elseif ( $city == '' && $state != '' ) {
				$state = ( $state != '' ) ? $state . "\r\n" : '';
			}
			else {
				$city = ( $city != '' ) ? $city . "\r\n" : '';
			}
			$postcode     = ( $postcode != '' ) ? $postcode . "\r\n" : '';
			$country      = ( $country != '' ) ? $country . "\r\n" : '';
			$address      = $street . $city . $state . $postcode . $country;
			$custom_field = "\r\n" . $custom_field;
			$signature    = "\r\n\r\n--\r\n" . $first_name . " " . $last_name . "\r\n" . $email . "\r\n"  . $address . $custom_field . "\r\n";
			$message = html_entity_decode( $greeting . $petition->petition_message . $signature, ENT_QUOTES );
			$email_headers = "From: " . $first_name . " " . $last_name . " <" . $email . ">" . "\r\n";
			// send the email
			wp_mail( $petition->petition_email, $petition->petition_subject, $message, $email_headers );
		}
		// set up the confirmation status message
		$message = __( 'Thank you. Your signature has been added to the petition.', 'dk_speakup' );
	}
	// else, check if the signature has already been confirmed
	else {
		$confirmed_sql = "
			SELECT id
			FROM $db_signatures
			WHERE `confirmation_code` = '$confirmation_code' AND `confirmed` = '1'
		";
		$confirmed_result = $wpdb->get_row( $confirmed_sql );
		// if signature already confirmed...
		if ( count( $confirmed_result ) > 0 ) {
			$message = __( 'Your signature has already been confirmed.', 'dk_speakup' );
		}
		// else, the confirmation code is fubar
		// or the admin has already deleted the signature
		else {
			$message = __( 'The confirmation code you provided is invalid.', 'dk_speakup' );
		}
	}
	// construct page for displaying confirmation status message
	$confirmation_page = '
		<!DOCTYPE html>
		<html>
		<head>
			<meta http-equiv="Content-Type" content="text/xhtml; charset=' . get_bloginfo( "charset" ) . '" />
			<meta http-equiv="refresh" content="10;' . home_url() . '"> 
			<title>' . get_bloginfo( "name" ) . '</title>
			<style type="text/css">
				body {
					background: #ddd;
					font-family: arial, sans-serif;
					font-size: 14px;
				}
				#confirmation {
					background: #fff url(' . plugins_url( "speakup-email-petitions/images/mail-stripes.png" ) . ') repeat top left;
					border: 1px solid #fff;
					width: 515px;
					margin: 200px auto 0 auto;
					box-shadow: 0px 3px 5px #333;
				}
				#confirmation-content {
					background: #fff url(' . plugins_url( "speakup-email-petitions/images/postmark.png" ) . ') no-repeat top right;
					margin: 10px;
					padding: 40px 0 20px 100px;
				}
			</style>
		</head>
		<body>
			<div id="confirmation">
				<div id="confirmation-content">
					<h2>' . __( "Email Confirmation", "dk_speakup" ) . '</h2>
					<p>' . $message . '</p>
					<p>' . __( "You will be redirected momentarily.", "dk_speakup" ) . '</p>
					<p><a href="' . home_url() . '">' . get_bloginfo( "name" ) . '  &raquo;</a></p>
				</div>
			</div>
		</body>
		</html>
	';
	// display confirmation status message
	echo $confirmation_page;

	// stop page rendering here
	// without this, the home page will display below the confirmation message
	die();
}

?>