<?php

// register shortcode to display public petition form
add_shortcode( 'emailpetition', 'dk_speakup_emailpetition_shortcode' );
function dk_speakup_emailpetition_shortcode( $attr ) {

	global $wpdb, $db_petitions, $db_signatures;
	$options = get_option( 'dk_speakup_options' );

	// only query a petition if the "id" attribute has been set
	if ( isset( $attr['id'] ) && is_numeric( $attr['id'] ) ) {

		// get petition data from database
		$id = $attr['id'];
		$petition = dk_speakup_get_petition( $id );

		// if a petition with the specified id exists, try to display it
		if ( !empty( $petition ) ) {

			// if petition has expired, display expiration notice
			$expired = ( $petition->expires == '1' && time() >= strtotime( $petition->expiration_date ) ) ? 1 : 0;

			if ( $expired ) {
				$goal_text = ( $petition->signature_goal != 0 ) ? '<div class="dk-speakup-expired-goal"><span>' . __( 'Signature goal', 'dk_speakup' ) . ':</span> ' . $petition->signature_goal . '</div>' : '';
				$petition_form = '
					<div class="dk-speakup-petition-wrap" id="dk-speakup-petition-' . $id . '">
						<h3>' . $petition->petition_title . '</h3>
						<div class="dk-speakup-notice">
							<p>' . $options['expiration_message'] . '</p>
							<div class="dk-speakup-expired-deadline">
								<span>' . __( 'End date', 'dk_speakup' ) . ':</span> ' . date( 'M d, Y', strtotime( $petition->expiration_date ) ) . '
							</div>
							<div class="dk-speakup-expired-signatures">
								<span>' . __( 'Signatures collected', 'dk_speakup' ) . ':</span> ' . $petition->signatures . '
							</div>
							' . $goal_text . '
						</div>
						' . dk_speakup_public_goal_progress( $petition->signature_goal, $petition->signatures, 250, 0 ) . '
					</div>
				';
			}
			// else display petition form
			else {
				// get firstname, lastname and email for logged in users
				$userdata = dk_speakup_get_userinfo();

				/* Configure optional fields
				------------------------------ */
				// Greeting
				$greeting = ( $petition->petition_greeting != '' && $petition->send_email == 1 ) ? '<p><span class="dk-speakup-greeting">' . $petition->petition_greeting . '</span></p>' : '';

				/* Address fields
				------------------------------ */
				$address_fields = unserialize( $petition->address_fields );

				// Street
				$street = '';
				if ( in_array( 'street', $address_fields ) ) {
					$street = '
						<div class="dk-speakup-full">
							<label for="dk-speakup-street-' . $id . '">' . __( 'Street', 'dk_speakup' ) . '</label>
							<input name="dk-speakup-street" id="dk-speakup-street-' . $id . '" class="dk-speakup-street" maxlength="200" type="text">
						</div>
					';
				}


				// City
				$city = '';
				if ( in_array( 'city', $address_fields ) ) {
					$city = '
						<div class="dk-speakup-half">
							<label for="dk-speakup-city-' . $id . '">' . __( 'City', 'dk_speakup' ) . '</label>
							<input name="dk-speakup-city" id="dk-speakup-street-' . $id . '" class="dk-speakup-city" maxlength="200" type="text">
						</div>
					';
				}

				// State
				$state = '';
				if ( in_array( 'state', $address_fields ) ) {
					$state = '
						<div class="dk-speakup-half">
							<label for="dk-speakup-state-' . $id . '">' . __( 'State / Province', 'dk_speakup' ) . '</label>
							<input name="dk-speakup-state" id="dk-speakup-state-' . $id . '" class="dk-speakup-state" maxlength="200" type="text">
						</div>
					';
				}

				// Post Code
				$postcode = '';
				if ( in_array( 'postcode', $address_fields ) ) {
					$postcode = '
						<div class="dk-speakup-half">
							<label for="dk-speakup-postcode-' . $id . '">' . __( 'Post Code', 'dk_speakup' ) . '</label>
							<input name="dk-speakup-postcode" id="dk-speakup-postcode-' . $id . '" class="dk-speakup-postcode" maxlength="200" type="text">
						</div>
					';
				}

				// Country
				$country = '';
				if ( in_array( 'country', $address_fields ) ) {
					$country = '
						<div class="dk-speakup-half">
							<label for="dk-speakup-country-' . $id . '">' . __( 'Country', 'dk_speakup' ) . '</label>
							<input name="dk-speakup-country" id="dk-speakup-country-' . $id . '" class="dk-speakup-country" maxlength="200" type="text">
						</div>
					';
				}

				// Custom Field
				$custom_field = '';
				if ( $petition->display_custom_field == '1' ) {
					$custom_field = '
						<div class="dk-speakup-half">
							<label for="dk-speakup-custom-field-' . $id . '">' . $petition->custom_field_label . '</label>
							<input name="dk-speakup-custom-field" id="dk-speakup-custom-field-' . $id . '" class="dk-speakup-custom-field" maxlength="200" type="text" />
						</div>
					';
				}

				// Email Opt-in
				$email_optin = '';
				if ( $petition->display_email_optin == '1' ) {
					// determine if box should be checked by default
					$optin_default = ( $options['optin_default'] == 'checked' ) ? 'checked' : '';
					// compose HTML
					$email_optin = '
						<div class="dk-speakup-optin-wrap">
							<input type="checkbox" name="dk-speakup-optin" id="dk-speakup-optin-' . $id . '" class="dk-speakup-optin"' . $optin_default . ' />
							<label for="dk-speakup-optin-' . $id . '">' . $petition->email_optin_label . '</label>
						</div>
					';
				}

				// Signature count and progress bar
				$progress_count = '';
				if ( $options['display_count'] == '1' ) {
					$progress_count = dk_speakup_public_goal_progress( $petition->signature_goal, $petition->signatures, 150, $petition->has_signature_goal );
				}

				$petition_form = '
					<div class="dk-speakup-petition-wrap" id="dk-speakup-petition-' . $id . '">
						<h3>' . $petition->petition_title . '</h3>
						<div class="dk-speakup-response"></div>
						<form class="dk-speakup-petition">
							<input type="hidden" name="dk-speakup-id" class="dk-speakup-id" value="' . $id . '" />
							<input type="hidden" class="dk-speakup-permalink" value="' . get_permalink() .'" />
							<input type="hidden" class="dk-speakup-posttitle" value="' . esc_attr( urlencode( get_the_title() ) ) .'" />
							<input type="hidden" class="dk-speakup-twitter-message" value="' . dk_speakup_twiter_encode( $petition->twitter_message ) .'" />
							<div class="dk-speakup-half">
								<label for="dk-speakup-first-name-' . $id . '" class="required">' . __( 'First Name', 'dk_speakup' ) . '</label>
								<input name="dk-speakup-first-name" id="dk-speakup-first-name-' . $id . '" class="dk-speakup-first-name" value="' . $userdata['firstname'] . '" type="text" />
							</div>
							<div class="dk-speakup-half">
								<label for="dk-speakup-last-name-' . $id . '" class="required">' . __( 'Last Name', 'dk_speakup' ) . '</label>
								<input name="dk-speakup-last-name" id="dk-speakup-last-name-' . $id . '" class="dk-speakup-last-name" value="' . $userdata['lastname'] . '" type="text" />
							</div>
							<div class="dk-speakup-full">
								<label for="dk-speakup-email-' . $id . '" class="required">' . __( 'Email', 'dk_speakup' ) . '</label>
								<input name="dk-speakup-email" id="dk-speakup-email-' . $id . '" class="dk-speakup-email" value="' . $userdata['email'] . '" type="text" />
							</div>
							' . $street . '
							' . $city . '
							' . $state . '
							' . $postcode . '
							' . $country . '
							' . $custom_field . '
							<div class="dk-speakup-full">
								<div name="dk-speakup-message" id="dk-speakup-message-' . $id . '" class="dk-speakup-message">' . $greeting . wpautop( $petition->petition_message ) . '<span class="dk-speakup-pseudo-signature">[' . __( 'Your Signature', 'dk_speakup' ) . ']</span>' . '</div>
							</div>
							' . $email_optin . '
							<div class="dk-speakup-submit-wrap">
								<a name="dk-speakup-petition-' . $id . '" class="dk-speakup-submit"><span>' . $options['button_text'] . '</span></a>
							</div>
							' . $progress_count . '
						</form>
						<div class="dk-speakup-share">
							<p><strong>' . $share_message = $options['share_message'] . '</strong></p>
							<a class="dk-speakup-facebook" href="#" title="Facebook"></a>
							<a class="dk-speakup-twitter" href="#" title="Twitter"></a>
							<div class="dk-speakup-clear"></div>
						</div>
					</div>
				';
			}

		}
		// ...otherwise, display nothing
		// most likely scenario is a user deletes an old petition, but fails to remove shortcode from their post
		else {
			$petition_form = '';
		}
	}

	// if id attribute is left out, as in [emailpetition], display error
	else {
		$petition_form = '
			<div class="dk-speakup-petition-wrap">
				<div class="dk-speakup-notice">
					<p><strong>SpeakUp! Email Petitions</strong></p>
					<p>' . __( 'Error: You must include a valid id.', 'dk_speakup' ) . '</p>
				</div>
			</div>
		';
	}

	return $petition_form;
}

// register shortcode to display signatures list
add_shortcode( 'signaturelist', 'dk_speakup_signatures_shortcode' );
function dk_speakup_signatures_shortcode( $attr ) {

	global $wpdb, $db_signatures;
	$options = get_option( 'dk_speakup_options' );
	$query_start = 0;
	$query_limit = $options['signaturelist_rows'];

	// only query a petition if the "petition" attribute has been set
	if ( isset( $attr['id'] ) && is_numeric( $attr['id'] ) ) {
		$id = $attr['id'];

		// limit query results if query limit set
		// if query limit is blank, get all signatures
		$limit = ( $query_limit == '' ) ? '' : 'LIMIT ' . $query_start . ', ' . $query_limit;

		// get the signatures for display
		$columns = unserialize( $options['signaturelist_columns'] );
		$signatures = dk_speakup_get_signatureslist( $id, $columns, $limit );

		// get total number of signatures
		// for setting the number of most recent signature in table
		$signatures_count = dk_speakup_get_signatures_total( $id );

		$total_signatures = count( $signatures_count );
		$current_signature_number = $total_signatures;

		// only show signature lists if there are signatures
		$signatures_list = '';
		if ( $total_signatures > 0 ) {
			// determine which columns to display
			$display_city     = ( in_array( 'sig_city', $columns ) ) ? 1 : 0;
			$display_state    = ( in_array( 'sig_state', $columns ) ) ? 1 : 0;
			$display_postcode = ( in_array( 'sig_postcode', $columns ) ) ? 1 : 0;
			$display_country  = ( in_array( 'sig_country', $columns ) ) ? 1 : 0;
			$display_custom   = ( in_array( 'sig_custom', $columns ) ) ? 1 : 0;
			$display_date     = ( in_array( 'sig_date', $columns ) ) ? 1 : 0;

			// write the HTML
			$signatures_list = '
				<h3 class="dk-speakup-signaturelist_header">' . $options['signaturelist_header'] . '</h3>
					<table class="dk-speakup-signaturelist">
			';

			foreach ( $signatures as $signature ) {
				$signatures_list .= '<tr>';
				$signatures_list .= '<td class="dk-speakup-signaturelist-count">' . number_format( $current_signature_number, 0, '.', ',' ) . '</td>';
				$signatures_list .= '<td class="dk-speakup-signaturelist-name">' . $signature->first_name . ' ' . $signature->last_name . '</td>';
				// if we display both city and state, combine them into one column
				$city  = ( $display_city )  ? $signature->city : '';
				$state = ( $display_state ) ? $signature->state : '';
				if ( $display_city && $display_state ) {
					// should we separate with a comma?
					$delimiter = ( $city !='' && $state != '' ) ? ', ' : '';
					$signatures_list .= '<td class="dk-speakup-signaturelist-city">' . $city . $delimiter . $state. '</td>';
				}
				// else keep city or state values in their own column
				else {
					if ( $display_city ) $signatures_list  .= '<td class="dk-speakup-signaturelist-city">' . $city . '</td>';
					if ( $display_state ) $signatures_list .= '<td class="dk-speakup-signaturelist-state">' . $state . '</td>';
				}
				if ( $display_postcode ) $signatures_list .= '<td class="dk-speakup-signaturelist-postcode">' . $signature->postcode . '</td>';
				if ( $display_country ) $signatures_list  .= '<td class="dk-speakup-signaturelist-country">' . $signature->country . '</td>';
				if ( $display_custom ) $signatures_list   .= '<td class="dk-speakup-signaturelist-custom">' . $signature->custom_field. '</td>';
				if ( $display_date ) $signatures_list     .= '<td class="dk-speakup-signaturelist-date">' . date_i18n( 'M d, Y', strtotime( $signature->date ) ) . '</td>';
				$signatures_list .= '</tr>';
 
				$current_signature_number --;
			}
			$signatures_list .= '</table>';
		}

		return $signatures_list;
	}
}

// load public CSS only on pages/posts that contain the [emailpetition] shortcode
add_filter( 'the_posts', 'dk_speakup_public_css_js' );
function dk_speakup_public_css_js( $posts ) {

	// ignore if there are no posts
	if ( empty( $posts ) ) return $posts;

	$options = get_option( 'dk_speakup_options' );

	// set flag to determine if post contains shortcode
	$shortcode_found = false;

	foreach ( $posts as $post ) {
		// if post content contains the shortcode
		if ( strstr( $post->post_content, '[emailpetition' ) ) {
			// update flag
			$shortcode_found = true;
			break;
		}
	}

	// if flag is now true, load the CSS and JavaScript once
	if ( $shortcode_found ) {
		// load the correct CSS theme
		$theme = $options['petition_theme'];
		switch( $theme ) {
			case 'standard' :
				wp_enqueue_style( 'dk_speakup_css', plugins_url( 'speakup-email-petitions/css/theme-standard.css' ) );
				break;
			case 'basic' :
				wp_enqueue_style( 'dk_speakup_css', plugins_url( 'speakup-email-petitions/css/theme-basic.css' ) );
				break;
			case 'none' :
				// look for custom theme file, petition.css

				$parent_dir = get_template_directory_uri();
				$parent_petition_theme_url = $parent_dir . '/petition.css';

				// if a child theme is in use
				// try to find petition.css in child theme
				if ( is_child_theme() ) {
					$child_dir = get_stylesheet_directory_uri();
					$child_petition_theme_url = $child_dir . '/petition.css';
					$child_petition_theme_path = STYLESHEETPATH . '/petition.css';
					// use child theme if it exists
					if ( file_exists( $child_petition_theme_path ) ) {
						wp_enqueue_style( 'dk_speakup_css', $child_petition_theme_url );
					}
					// else try to load parent's custom theme
					else {
						wp_enqueue_style( 'dk_speakup_css', $parent_petition_theme_url );
					}
				}
				// if not using a child theme, just try to load petition.css in active theme folder
				else {
					wp_enqueue_style( 'dk_speakup_css', $parent_petition_theme_url );
				}
				break;
		}

		wp_enqueue_script( 'dk_speakup_js', plugins_url( 'speakup-email-petitions/js/public.js' ), array( 'jquery' ) );

		// make sure ajax callback url works on both https and http
		$protocol = isset( $_SERVER['HTTPS'] ) ? 'https://' : 'http://';
		$params = array(
			'ajaxurl' => admin_url( 'admin-ajax.php', $protocol )
		);
		wp_localize_script( 'dk_speakup_js', 'dk_speakup_js', $params );
	}

	return $posts;
}

// load CSS on pages/posts that contain the [signaturelist] shortcode
add_filter( 'the_posts', 'dk_speakup_signaturelist_css' );
function dk_speakup_signaturelist_css( $posts ) {

	// ignore if there are no posts
	if ( empty( $posts ) ) return $posts;

	// set flag to determine if post contains shortcode
	$shortcode_found = false;

	foreach ( $posts as $post ) {
		// if post content contains the shortcode
		if ( strstr( $post->post_content, '[signaturelist' ) ) {
			// update flag
			$shortcode_found = true;
			break;
		}
	}

	// if flag is now true, load the CSS once
	if ( $shortcode_found ) {
		wp_enqueue_style( 'dk_speakup_signaturelist_css', plugins_url( 'speakup-email-petitions/css/signaturelist.css' ) );
	}

	return $posts;
}

?>