<?php

// register widget
add_action( 'widgets_init', 'dk_speakup_register_widgets' );
function dk_speakup_register_widgets() {
	register_widget( 'dk_speakup_petition_widget' );
}

class dk_speakup_petition_widget extends WP_Widget {

	function dk_speakup_petition_widget() {
		$widget_ops = array(
			'classname' => 'dk_speakup_widget',
			'description' => __( 'Display a petition form.', 'dk_speakup' )
		);
		$this->WP_Widget( 'dk_speakup_petition_widget', 'SpeakUp! Email Petitions', $widget_ops );

		// load widget scripts
		if ( ! is_admin() && is_active_widget( false, false, $this->id_base, true ) ) {
			wp_enqueue_script( 'dk_speakup_widget_js', plugins_url( 'speakup-email-petitions/js/widget.js' ), array( 'jquery' ) );
			wp_enqueue_style( 'dk_speakup_widget_css', plugins_url( 'speakup-email-petitions/css/widget.css' ) );

			// set up AJAX callback script
			$protocol = isset( $_SERVER['HTTPS'] ) ? 'https://' : 'http://';
			$params = array( 'ajaxurl' => admin_url( 'admin-ajax.php', $protocol ) );
			wp_localize_script( 'dk_speakup_widget_js', 'dk_speakup_widget_js', $params );
		}
	}

	// create widget form (admin)
	function form( $instance ) {
		$options = get_option( 'dk_speakup_options' );
		$defaults = array( 'title' => $options['petition_header'], 'call_to_action' => '', 'petition_id' => '1' );
		$instance = wp_parse_args( ( array ) $instance, $defaults );
		$title = $instance['title'];
		$call_to_action = $instance['call_to_action'];
		$petition_id = $instance['petition_id'];

		global $wpdb, $db_petitions;
		// select available petitions from db
		$sql = "
			SELECT id, petition_title
			FROM `$db_petitions`
		";
		$results = $wpdb->get_results( $sql );

		// display the form (admin)
		echo '<p><label>' . __( 'Title', 'dk_speakup' ) . ':</label><br /><input class="widefat" type="text" name="' . $this->get_field_name( 'title' ) . '" value="' . $instance['title'] . '"></p>';
		echo '<p><label>' . __( 'Call to Action', 'dk_speakup' ) . ':</label><br /><textarea maxlength="140" class="widefat" name="' . $this->get_field_name( 'call_to_action' ) . '">' . $instance['call_to_action'] . '</textarea></p>';
		echo '<p><label>' . __( 'Petition', 'dk_speakup' ) . ':</label><br /><select class="widefat" name="' . $this->get_field_name( 'petition_id' ) . '">';
		foreach ( $results as $petition  ) {
			$selected = $petition_id == $petition->id ? ' selected="selected"' : '';
			echo '<option value="' . $petition->id . '" ' . $selected . '>' . esc_html( $petition->petition_title ) . '</option>';
		}
		echo '</select></p>';
	}

	// save the widget settings (admin)
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['call_to_action'] = strip_tags( $new_instance['call_to_action'] );
		$instance['petition_id'] = $new_instance['petition_id'];

		return $instance;
	}

	// display widget (public)
	function widget( $args, $instance ) {

		global $wpdb, $db_petitions, $db_signatures;
		$options = get_option( 'dk_speakup_options' );
		extract( $args );

		// get widget data
		$title = apply_filters( 'widget_title', $instance['title'] );
		$call_to_action = empty( $instance['call_to_action'] ) ? '&nbsp;' : $instance['call_to_action'];
		$id = empty( $instance['petition_id'] ) ? '1' : $instance['petition_id'];
		$petition = dk_speakup_get_petition( $id );

		// get firstname, lastname and email for logged in users
		$userdata = dk_speakup_get_userinfo();

		/* Configure optional fields */
		// Greeting
		$greeting = ( $petition->petition_greeting != '' && $petition->send_email == 1 ) ? '<p><span class="dk-speakup-widget-greeting">' . $petition->petition_greeting . '</span></p>' : '';

		/* Address fields
		------------------------------ */
		$address_fields = unserialize( $petition->address_fields );

		// Street
		$street = '';
		if ( in_array( 'street', $address_fields ) ) {
			$street = '
				<div class="dk-speakup-widget-full">
					<label for="dk-speakup-widget-street-' . $id . '">' . __( 'Street', 'dk_speakup' ) . '</label>
					<input name="dk-speakup-widget-street" id="dk-speakup-widget-widget-street-' . $id . '" class="dk-speakup-widget-input dk-speakup-widget-street" maxlength="200" type="text">
				</div>
			';
		}

		// City
		$city = '';
		if ( in_array( 'city', $address_fields ) ) {
			$city = '
				<div class="dk-speakup-widget-half">
					<label for="dk-speakup-widget-city-' . $id . '">' . __( 'City', 'dk_speakup' ) . '</label>
					<input name="dk-speakup-widget-city" id="dk-speakup-widget-city-' . $id . '" class="dk-speakup-widget-input dk-speakup-widget-city" maxlength="200" type="text">
				</div>
			';
		}

		// State
		$state = '';
		if ( in_array( 'state', $address_fields ) ) {
			$state = '
				<div class="dk-speakup-widget-half">
					<label for="dk-speakup-widget-state-' . $id . '">' . __( 'State / Province', 'dk_speakup' ) . '</label>
					<input name="dk-speakup-widget-state" id="dk-speakup-widget-state-' . $id . '" class="dk-speakup-widget-input dk-speakup-widget-state" maxlength="200" type="text">
				</div>
			';
		}

		// Post Code
		$postcode = '';
		if ( in_array( 'postcode', $address_fields ) ) {
			$postcode = '
				<div class="dk-speakup-widget-half">
					<label for="dk-speakup-widget-postcode-' . $id . '">' . __( 'Post Code', 'dk_speakup' ) . '</label>
					<input name="dk-speakup-widget-postcode" id="dk-speakup-widget-postcode-' . $id . '" class="dk-speakup-widget-input dk-speakup-widget-postcode" maxlength="200" type="text">
				</div>
			';
		}

		// Country
		$country = '';
		if ( in_array( 'country', $address_fields ) ) {
			$country = '
				<div class="dk-speakup-widget-half">
					<label for="dk-speakup-widget-country-' . $id . '">' . __( 'Country', 'dk_speakup' ) . '</label>
					<input name="dk-speakup-widget-country" id="dk-speakup-widget-country-' . $id . '" class="dk-speakup-widget-input dk-speakup-widget-country" maxlength="200" type="text">
				</div>
			';
		}

		// Custom field
		if( $petition->display_custom_field == '1' ) {
			$custom_field = '
				<div class="dk-speakup-widget-half">
					<label for="dk-speakup-widget-custom-field-' . $id . '">' . $petition->custom_field_label . '</label>
					<input name="dk-speakup-widget-custom-field" id="dk-speakup-widget-custom-field-' . $id . '" class="dk-speakup-widget-input dk-speakup-widget-custom-field" type="text">
				</div>
			';
		}
		else {
			$custom_field = '';
		}

		// Email opt-in checkbox
		if( $petition->display_email_optin == '1' ) {
			// determine if box should be checked by default
			$optin_default = ( $options['optin_default'] == 'checked' ) ? 'checked' : '';
			// compose HTML
			$email_optin = '
				<div class="dk-speakup-widget-optin-wrap">
					<input type="checkbox" name="dk-speakup-widget-optin" id="dk-speakup-widget-optin-' . $id . '" class="dk-speakup-widget-optin"' . $optin_default . ' />
					<label for="dk-speakup-widget-optin-' . $id . '">' . $petition->email_optin_label . '</label>
				</div>
			';
		}
		else {
			$email_optin = '';
		}

		// Signature count and progress bar
		if ( $options['display_count'] == '1' ) {
			$progress_count = dk_speakup_public_goal_progress( $petition->signature_goal, $petition->signatures, 150, $petition->has_signature_goal, 1 );
		}
		else {
			$progress_count = '';
		}

		// compose the petition widget and pop-up form
		echo '
			<!-- SpeakUp! Email Petitions Widget -->
			<div class="dk-speakup-widget-wrap" id="dk-speakup-petition-' . $id . '">
				<h3>' . $title . '</h3>
				<p>' . $call_to_action . '</p>
				<p class="dk-speakup-widget-button-wrap">
					<a rel="dk-speakup-widget-popup-wrap-' . $id . '" class="dk-speakup-widget-button"><span>' . $options['button_text'] . '</span></a>
				</p>
				' . $progress_count . '
			</div>

			<!-- SpeakUp! Email Petitions Widget Pop-Up -->
			<div id="dk-speakup-windowshade"></div>
			<div id="dk-speakup-widget-popup-wrap-' . $id . '" class="dk-speakup-widget-popup-wrap">
				<h3>' . $petition->petition_title . '</h3>
				<div class="dk-speakup-widget-close"></div>
				<div class="dk-speakup-widget-message-wrap">
					<div name="dk-speakup-widget-message" id="dk-speakup-widget-message-' . $id . '" class="dk-speakup-widget-message">' . $greeting . wpautop( $petition->petition_message ) . '<span class="dk-speakup-pseudo-signature">[' . __( 'Your Signature', 'dk_speakup' ) . ']</span></div>
				</div>
				<div class="dk-speakup-widget_form-wrap">
					<div class="dk-speakup-widget-response"></div>
					<form class="dk-speakup-widget-form">
						<input type="hidden" name="dk-speakup-widget-id" class="dk-speakup-widget-id" value="' . $id . '" />
						<input type="hidden" class="dk-speakup-widget-permalink" value="' . get_permalink() .'" />
						<input type="hidden" class="dk-speakup-widget-posttitle" value="' . esc_attr( urlencode( get_the_title() ) ) .'" />
						<input type="hidden" class="dk-speakup-widget-twitter-message" value="' . $petition->twitter_message .'" />
		';
		
		// if petition has expired, display expiration notice
		$expired = ( $petition->expires == '1' && time() >= strtotime( $petition->expiration_date ) ) ? 1 : 0;
		
		if ( $expired ) {
			$goal_text = ( $petition->signature_goal != 0 ) ? '<div class="dk-speakup-expired-goal"><span>' . __( 'Signature goal', 'dk_speakup' ) . ':</span> ' . $petition->signature_goal . '</div>' : '';

			echo '
				<p><strong>' . $options['expiration_message'] . '</strong></p>
				<p>' . __( 'End date', 'dk_speakup' ) . ': ' . date( 'M d, Y', strtotime( $petition->expiration_date ) ) . '</p>
				<p>' . __( 'Signatures collected', 'dk_speakup' ) . ': ' . $petition->signatures . '</p>
				<p>' . $goal_text . '</p>
			';
		}
		else {
			echo '
				<p>' . $call_to_action . '</p>
				<div class="dk-speakup-widget-half">
					<label for="dk-speakup-widget-first-name-' . $id . '" class="required">' . __( 'First Name', 'dk_speakup' ) . '</label>
					<input name="dk-speakup-widget-first-name" id="dk-speakup-widget-first-name-' . $id . '" class="dk-speakup-widget-input dk-speakup-widget-first-name" value="' . $userdata['firstname'] . '" type="text" />
				</div>
				<div class="dk-speakup-widget-half">
					<label for="dk-speakup-widget-last-name-' . $id . '" class="required">' . __( 'Last Name', 'dk_speakup' ) . '</label>
					<input name="dk-speakup-widget-last-name" id="dk-speakup-widget-last-name-' . $id . '" class="dk-speakup-widget-input dk-speakup-widget-last-name" value="' . $userdata['lastname'] . '" type="text" />
				</div>
				<div class="dk-speakup-widget-full">
					<label for="dk-speakup-widget-email-' . $id . '" class="required">' . __( 'Email', 'dk_speakup' ) . '</label>
					<input name="dk-speakup-widget-email" id="dk-speakup-widget-email-' . $id . '" class="dk-speakup-widget-input dk-speakup-widget-email" value="' . $userdata['email'] . '" type="text" />
				</div>
				' . $street . '
				' . $city . '
				' . $state . '
				' . $postcode . '
				' . $country . '
				' . $custom_field . '
				' . $email_optin . '
				<div class="dk-speakup-widget-submit-wrap">
					<a name="dk-speakup-widget-popup-wrap-' . $id . '" class="dk-speakup-widget-submit"><span>' . $options['button_text'] . '</span></a>
				</div>
			';
		}
			echo '
				</form>
				<div class="dk-speakup-widget-share">
					<p><strong>' . $share_message = $options['share_message'] . '</strong></p>
					<a class="dk-speakup-widget-facebook" href="#" title="Facebook"></a>
					<a class="dk-speakup-widget-twitter" href="#" title="Twitter"></a>
					<div class="dk-speakup-clear"></div>
				</div>
			</div>
		</div>
		';
	}

}

?>